package com.javaseleniumtemplate.tests;

import com.javaseleniumtemplate.bases.TestBase;
import com.javaseleniumtemplate.flows.LoginFlows;
import com.javaseleniumtemplate.flows.ParametrosDePlanejamentoFlows;
import org.testng.Assert;
import org.testng.annotations.Test;

public class ParametrosDePlanejamentoTests extends TestBase {

    LoginFlows loginFlows;
    ParametrosDePlanejamentoFlows parametrosDePlanejamentoFlows;


    public void acessarTela(){
        loginFlows = new LoginFlows();
        String NMTELA = "Parâmetros de Planejamento";
        parametrosDePlanejamentoFlows = new ParametrosDePlanejamentoFlows();
        loginFlows.efetuarLogin();
        parametrosDePlanejamentoFlows.acessarTela();
        Assert.assertEquals(NMTELA,parametrosDePlanejamentoFlows.validaTela(),"Confirma acesso tela: ");
    }

    @Test
    public void acessarTelaParametros(){
        acessarTela();
        parametrosDePlanejamentoFlows.editaPersonalizacao();
    }

    @Test
    public void editarAbaCardapio(){
        acessarTela();
        parametrosDePlanejamentoFlows.edicaoAbaCardapio();
    }

    @Test
    public void calculoNDPCAL(){
        String MSESPERADA = "Não há registros";
        acessarTela();
        parametrosDePlanejamentoFlows.calculoNdpcal();
        Assert.assertEquals(MSESPERADA,parametrosDePlanejamentoFlows.validaExclusao(), "Validando se o registro foi apagado:");
    }

    @Test
    public void abaSafra(){
        String VRINICOFAIXA = "1";
        String VRFIMFAIXA = "1";
        String VRINICIOFAIXA = "2";
        String VRFINALFAIXA = "2";
        String MSDESCESPERADA = "TESTE AUTOMAÇÃO";
        String MSDESCESPERADA_2 = "AUTOMAÇÃO";
        String MSESPERADA = "Não há registros";
        acessarTela();
        parametrosDePlanejamentoFlows.cadastraAbaSafra();
        Assert.assertEquals(VRINICOFAIXA,parametrosDePlanejamentoFlows.validaCadastro(),"Validando dados cadastrados :");
        Assert.assertEquals(VRFIMFAIXA,parametrosDePlanejamentoFlows.confirmaCadastro(),"Validando dados cadastrados :");
        Assert.assertEquals(VRINICIOFAIXA,parametrosDePlanejamentoFlows.confirmarCadastro(),"Validando dados cadastrados :");
        Assert.assertEquals(VRFINALFAIXA,parametrosDePlanejamentoFlows.validarCadastro(),"Validando dados cadastrados :");
        parametrosDePlanejamentoFlows.editarSafra();
        Assert.assertEquals(MSDESCESPERADA,parametrosDePlanejamentoFlows.validaEdicao(),"Validando se os registros foram editados e salvos corretamente:");
        Assert.assertEquals(MSDESCESPERADA_2,parametrosDePlanejamentoFlows.validarEdicao(),"Validando se os registros foram editados e salvos corretamente:");
        parametrosDePlanejamentoFlows.excluirSafra();
        Assert.assertEquals(MSESPERADA,parametrosDePlanejamentoFlows.validaExclusao(),"Validando se o registro foi apagado:");
    }

    @Test
    public void grupoDeOperadores(){
        String MSESPERADA = "6 | ADMINISTRADOR";
        acessarTela();
        parametrosDePlanejamentoFlows.grupoDeOperadores();
        Assert.assertEquals(MSESPERADA,parametrosDePlanejamentoFlows.validaGrupoAlteraReqServico(),"Validando se o grupo foi gravado corretamente");
        Assert.assertEquals(MSESPERADA,parametrosDePlanejamentoFlows.validaGrupoAlteraReqExtra(),"Validando se o grupo foi gravado corretamente");
        Assert.assertEquals(MSESPERADA,parametrosDePlanejamentoFlows.validaGrupoReceitaPadrao(),"Validando se o grupo foi gravado corretamente");
        Assert.assertEquals(MSESPERADA,parametrosDePlanejamentoFlows.validaGrupoAlteraReceitaRevisada(),"Validando se o grupo foi gravado corretamente");
        Assert.assertEquals(MSESPERADA,parametrosDePlanejamentoFlows.validaGrupoGravaDtRefCusto(),"Validando se o grupo foi gravado corretamente");
        Assert.assertEquals(MSESPERADA,parametrosDePlanejamentoFlows.validaGrupoGravaDtRefRecalculoCusto(),"Validando se o grupo foi gravado corretamente");
        Assert.assertEquals(MSESPERADA,parametrosDePlanejamentoFlows.validaGrupoLiberaCardForaMeta(),"Validando se o grupo foi gravado corretamente");
        Assert.assertEquals(MSESPERADA,parametrosDePlanejamentoFlows.validaGrupoAlteraCustoPadrao(),"Validando se o grupo foi gravado corretamente");
        Assert.assertEquals(MSESPERADA,parametrosDePlanejamentoFlows.validaGrupoLiberaCardapioDescMatriz(),"Validando se o grupo foi gravado corretamente");
        Assert.assertEquals(MSESPERADA,parametrosDePlanejamentoFlows.validaGrupoAutorizaSubsPratoLiberadoProd(),"Validando se o grupo foi gravado corretamente");
        Assert.assertEquals(MSESPERADA,parametrosDePlanejamentoFlows.validaGrupoAcessoOtimizador(),"Validando se o grupo foi gravado corretamente");

    }

    @Test
    public void avisoAprovacaoCardapio(){
        String NRDIAS = "5";
        String NRDIA = "3";
        String MSGAVISO = "Aprovação de Cardápio!!";
        String MSESPERADA = "Aprovação de Cardápio Próximo da data Limite!!";
        String NOVAMSG = "Aprovar Cardápio Urgente!!";
        String MSGESPERADA = "Tempo limite para aprovação chegando!!";
        String MSEXCLUSAO = "Não há registros";

        acessarTela();
        parametrosDePlanejamentoFlows.cadastraAvisoCardapio();
        Assert.assertEquals(NRDIAS,parametrosDePlanejamentoFlows.retornaDiasAviso(),"Dias de Aviso: ");
        Assert.assertEquals(MSESPERADA,parametrosDePlanejamentoFlows.retornarCadastroMensagem(),"Mensagem Cadastrada: ");
        Assert.assertEquals(NRDIA,parametrosDePlanejamentoFlows.retornarCadastroDiasAviso(),"Dias de Aviso: ");
        Assert.assertEquals(MSGAVISO,parametrosDePlanejamentoFlows.retornaCadastroMensagem(),"Mensagem Cadastrada: ");
        parametrosDePlanejamentoFlows.editarMensagemAviso();
        Assert.assertEquals(NOVAMSG,parametrosDePlanejamentoFlows.confirmaEdicaoMensagem(),"Validando se a mensagem foi editada e salva corretamente: ");
        Assert.assertEquals(MSGESPERADA,parametrosDePlanejamentoFlows.confirmarEdicaoMensagem(),"Validando se a mensagem foi editada e salva corretamente: ");
        parametrosDePlanejamentoFlows.excluirMensagemAvisoCardapio();
        Assert.assertEquals(MSEXCLUSAO,parametrosDePlanejamentoFlows.validaExclusao(),"Valida se os registros foram apagados: ");
    }

    @Test
    public void avaliacaoVet(){
        String NMDESCR = "NUTRIENTES";
        String VRCHO = "90,000";
        String VRPTN = "5,000";
        String VRLIP = "5,000";
        String NMDESC = "COMPRAS";
        String VALCHO = "50,000";
        String VALPTN = "25,000";
        String VALLIP = "25,000";
        String NMEDITADO = "AUTOMAÇÃO";
        String CHOATU =  "60,000";
        String PTNATU =  "20,000";
        String LIPATU =  "20,000";
        String CHO_ATU = "40,000";
        String PTN_ATU = "40,000";
        String LIP_ATU = "20,000";
        String MSEXCLUSAO = "Não há registros";

        acessarTela();
        parametrosDePlanejamentoFlows.cadastraAvaliacaoVet();
        Assert.assertEquals(NMDESCR,parametrosDePlanejamentoFlows.validaCadastroDesc(),"Validando descrição salva: ");
        Assert.assertEquals(VRCHO,parametrosDePlanejamentoFlows.validaCadastroCho(), "Validando valor CHO salvo: ");
        Assert.assertEquals(VRPTN,parametrosDePlanejamentoFlows.validaCadastroPtn(),"Validando valor PTN salvo: ");
        Assert.assertEquals(VRLIP,parametrosDePlanejamentoFlows.validaCadastroLip(), "Validando valor LIP salvo: ");
        Assert.assertEquals(NMDESC,parametrosDePlanejamentoFlows.validarCadastroDesc(),"Validando descrição salva: ");
        Assert.assertEquals(VALCHO,parametrosDePlanejamentoFlows.validarCadastroCho(), "Validando valor CHO salvo: ");
        Assert.assertEquals(VALPTN,parametrosDePlanejamentoFlows.validarCadastroPtn(),"Validando valor PTN salvo: ");
        Assert.assertEquals(VALLIP,parametrosDePlanejamentoFlows.validarCadastroLip(), "Validando valor LIP salvo: ");
        parametrosDePlanejamentoFlows.editarAvaliacaoVet();
        Assert.assertEquals(NMEDITADO,parametrosDePlanejamentoFlows.retornarDescAtual(),"Validando descrição salva Grupo 003: ");
        Assert.assertEquals(CHOATU,parametrosDePlanejamentoFlows.retornaValChoAtu(), "Validando valor CHO salvo Grupo 003: ");
        Assert.assertEquals(PTNATU,parametrosDePlanejamentoFlows.retornaValPtnAtu(),"Validando valor PTN salvo Grupo 003: ");
        Assert.assertEquals(LIPATU,parametrosDePlanejamentoFlows.retornaValLipAtu(), "Validando valor LIP salvo Grupo 003: ");
        Assert.assertEquals(NMEDITADO,parametrosDePlanejamentoFlows.retornarDescAtu(),"Validando descrição salva Grupo 005");
        Assert.assertEquals(CHO_ATU,parametrosDePlanejamentoFlows.retornarVlrChoAtu(),"Validando descrição salva Grupo 005: ");
        Assert.assertEquals(PTN_ATU,parametrosDePlanejamentoFlows.retornarVlrPtnAtu(), "Validando valor CHO salvo Grupo 005: ");
        Assert.assertEquals(LIP_ATU,parametrosDePlanejamentoFlows.retornarVlrLipAtu(),"Validando valor PTN salvo Grupo 005: ");
        parametrosDePlanejamentoFlows.excluirAvaliacaoVet();
        Assert.assertEquals(MSEXCLUSAO,parametrosDePlanejamentoFlows.validaExclusao(),"Valida se os registros foram apagados: ");
    }

}



